@@ -27,7 +27,7 @@ sub import {
 }
 
 # lazy builder for the RT client in $rt and the configuration in $config
-sub rt {
+sub _rt {
     unless ($rt) {
         $config = parse_config_file( $config_file );
 
@@ -86,11 +86,11 @@ Path::Iterator::Rule::RT - Extends Path::Iterator::Rule with custom rule subrout
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -126,7 +126,7 @@ sub check_owner {
     my $ticket;
     try {
         $ticket = RT::Client::REST::Ticket->new(
-            rt => rt(),
+            rt => _rt(),
             id => $id,
         )->retrieve;
     }
@@ -149,7 +149,7 @@ sub check_status {
     my $ticket;
     try {
         $ticket = RT::Client::REST::Ticket->new(
-            rt => rt(),
+            rt => _rt(),
             id => $id,
         )->retrieve;
     }
@@ -162,7 +162,6 @@ sub check_status {
 
 =head2 check_ticketSQL
 
-
 $rule->TicketSQL("Queue='General' AND Created = 'yesterday'");
 
 The TicketSQL is not as it appears. It has id=<directory name> added to it. So 
